@@ -79,7 +79,7 @@ class ReferenceKeys:
         if model not in self.__automodels__:
             raise KeyError(f"{model} is not supported!")
 
-    def detection_check(self, arg: Dict[str, Any]) -> None:
+    def detection_check(self, args: Dict[str, Any]) -> None:
         """Check if detection is available.
 
         Args:
@@ -90,8 +90,8 @@ class ReferenceKeys:
             KeyError: If the key is not parameter of the
                  `scipy.signal.find_peaks` function.
         """
-        if arg:
-            for key in arg:
+        if args:
+            for key in args:
                 if key.lower() not in self.__findpeaks__:
                     raise KeyError(
                         f"{key} is no function parameter of "
@@ -397,7 +397,6 @@ class ModelParameters(AutoPeakDetection):
                  Nested arguments dictionary for the model based on **one** or **two**
                  `int` keys depending if global fitting parameters, will explicit
                  defined or not.
-            params (Parameters): Parameters for the model.
 
         !!! note "About `args` for models"
 
@@ -755,6 +754,15 @@ class SolverModels(ModelParameters):
     ) -> NDArray[np.float64]:
         r"""Solving the fitting problem.
 
+        Args:
+            params (Dict[str, Parameters): The best-fit parameters resulting
+                 from the fit.
+            x (NDArray[np.float64]): `x`-values of the data.
+            data (NDArray[np.float64]): `y`-values of the data as 1d-array.
+
+        Returns:
+            NDArray[np.float64]: The best-fitted data based on the proposed model.
+
         !!! note "About implemented models"
             `solve_local_fitting` is a wrapper function for the calling the implemented
             moldels. Based on the `params` dictionary, the function calls the
@@ -778,16 +786,6 @@ class SolverModels(ModelParameters):
             [1]: https://en.wikipedia.org/wiki/Voigt_profile#Pseudo-Voigt_approximation
             [2]: https://en.wikipedia.org/wiki/Power_law
             [3]: https://en.wikipedia.org/wiki/Inverse_trigonometric_functions
-
-
-        Args:
-            params (Dict[str, Parameters): The best-fit parameters resulting
-                 from the fit.
-            x (NDArray[np.float64]): `x`-values of the data.
-            data (NDArray[np.float64]): `y`-values of the data as 1d-array.
-
-        Returns:
-            NDArray[np.float64]: The best-fitted data based on the proposed model.
         """
         val = np.zeros(x.shape)
         peak_kwargs: dict = defaultdict(dict)
@@ -901,11 +899,6 @@ def calculated_model(
 ) -> pd.DataFrame:
     r"""Calculate the single contributions of the models and add them to the dataframe.
 
-    !!! note "About calculated models"
-        `calculated_model` are also wrapper functions similar to `solve_model`. The
-        overall goal is to extract from the best parameters the single contributions in
-        the model. Currently, `lmfit` provides only a single model, so the best-fit.
-
     Args:
         params (dict): The best optimized parameters of the fit.
         x (NDArray[np.float64]): `x`-values of the data.
@@ -917,6 +910,11 @@ def calculated_model(
     Returns:
         pd.DataFrame: Extended dataframe containing the single contributions of the
             models.
+
+    !!! note "About calculated models"
+        `calculated_model` are also wrapper functions similar to `solve_model`. The
+        overall goal is to extract from the best parameters the single contributions in
+        the model. Currently, `lmfit` provides only a single model, so the best-fit.
     """
     peak_kwargs: dict = defaultdict(dict)
 
@@ -1027,8 +1025,6 @@ def voigt(
 
     Args:
         x (NDArray[np.float64]): `x`-values of the data.
-        amplitude (float, optional): Amplitude of the Voigt distribution. Defaults to
-             1.0.
         center (float, optional): Center of the Voigt distribution. Defaults to 0.0.
         fwhmv (float, optional): Full width at half maximum (FWHM) of the Lorentzian
              distribution. Defaults to 1.0.
